<?php
/**
 * Sleepy - a REST framework
 *
 *
 * A PHP Rest Framework valuing convention over configuration,
 * but aiming to be as flexible as possible
 *
 * @author Timothy J. Warren
 * @package Sleepy
 */

namespace Sleepy\Core;

// Include namespaces
use Aura\Di\Container as DiContainer;
use Aura\Di\Factory as DiFactory;
use Aura\Router\RouterFactory;

define('BASEPATH', __DIR__ . '/');
define('SLEEPY_DIR', 'Sleepy');
define('APP_DIR', 'application');
define('APPPATH', __DIR__ . '/application/');

// Include 3rd party dependencies
include BASEPATH . '/vendor/autoload.php';

// Load the autoloader
require BASEPATH . SLEEPY_DIR . '/autoload.php';

$di = new DiContainer(new DiFactory());

$rf = new RouterFactory();

$di->set('config', new Config());
$di->set('router', $rf->newInstance());
$di->set('input', new Input());
$di->set('output', new Output($di->get('config'), $di->get('input')));

$browser->browser_name_regex = \utf8_encode($browser->browser_name_regex);
$di->get('output')->set_data(['json','yaml','html'], [
	'$_SERVER' => $i->server(),
	'$_GET' => $i->get(),
	'$_POST' => $i->post(),
	'$_PUT' => $i->put(),
	'$_DELETE' => $i->delete(),
	'$_ENV' => $i->env(),
	'$_COOKIE' => $i->cookie(),
	'browser' => $browser,
	'raw headers' => $i->header(),
	'parsed headers' => $i->header_array()
]);

// End of index.php